pyardrone
=========
.. image:: https://travis-ci.org/afg984/pyardrone.svg?branch=master
    :target: https://travis-ci.org/afg984/pyardrone

Controlling ARDrone with Python

still work in progress...

Documentation
-------------

http://pyardrone.rtfd.org/
